<?php
  include_once("header.php");
  include_once("formvalidator.php"); 
  if(!$start)$start=0; 
       $validator = new FormValidator();
        $validator->addValidation('user_name','req','من فضلك ادخل  الاسم') ;
       $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;

       if(isset($submit)&&$validator->ValidateForm())
       {
          mysql_query("update user set 
          password='".md5($password)."',email='$email',country='$country',
          city='$city',phone='$phone',mobile='$mobile' where id='$user_id'");
          $msg="تم التعديل";
       }
       else
       {
           $userquery=mysql_query("select * from user where id='$_COOKIE[userid]'");
           while($userrow=mysql_fetch_array($userquery))
           {
             extract($userrow);
           }
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            } 
        $sub = Template_Array("$site_template/user_edit.html",0);
       }
  include_once("footer.php");
?>